@@ -475,8 +475,8 @@ def shell(command: str, ip: Optional[str] = None, **kwargs) -> ADBCommandResult:
     adb = get_adb_path()
     command_line = f"{ip_arg} shell"
     command_args = f"{command} {get_extra_arguments(**kwargs)}"
-    command_full = f'''{adb} "{command_line} {command_args}"'''.strip()
-    command_log = f'''adb "{command_line} {command_args}"'''.strip()
+    command_full = f'''{adb} {command_line} "{command_args}"'''.strip()
+    command_log = f'''adb {command_line} "{command_args}"'''.strip()
     log().debug(f"Executing `{command_log}`")
 
     out = subprocess.Popen(
